@@ -1,12 +1,13 @@
 <?php
-/*  $Id: setup.php,v 1.1 2002/01/15 22:43:07 dminor Exp $
+/*  $Id: setup.php,v 1.2 2002/12/11 06:30:55 dminor Exp $
  *  Login:Alias Plugin
  * 
  *  Copyright (C) 2001 Jay Guerette <JayGuerette_at_pobox.com>
  *  Copyright (C) 2002 David Minor <dave_at_dminor.com>
  *  
- *  Thanks to Christian Schneider <schneider_at_uni-dortmund.de>
- *  for his contribution.
+ *  Thanks to Christian Schneider <schneider_at_uni-dortmund.de> and
+ *	Emerson <emereson_at_inetintl.com>
+ *  for their contributions.
  *
  *  Please address questions about this plugin to the squirrelmail-plugins
  *  mailing list.
@@ -99,7 +100,18 @@ function login_alias_options_save() {
 
     $filename = $data_dir.'login_alias.pref';
     if (file_exists($filename) && (isset($login_alias) && $login_alias != '')) {
-        setPref($data_dir,$username,'login_alias',$login_alias);
+
+	/* Remove duplicated cached prefs for login_alias file */
+	$old_login_alias=getPref($data_dir,$username,'login_alias');
+	$alias_email=getPref($data_dir,'login_alias',$login_alias);
+	if ( $alias_email != $username && !empty($alias_email) ) {
+	    include_once( '../functions/display_messages.php');
+	    plain_error_message("Alias has already used. Please use another alias.", $color);	    
+	} else {
+            $prefs_are_cached = false;
+	    $prefs_cache = array();
+            cachePrefValues($data_dir, 'login_alias');
+	    removePref($data_dir,'login_alias',$old_login_alias);	
 
         /* change cached prefs for login_alias file */
         /* for writing changes                      */
@@ -108,11 +120,19 @@ function login_alias_options_save() {
         cachePrefValues($data_dir, 'login_alias');
         setPref($data_dir,'login_alias',$login_alias,$username);
 
+		$prefs_are_cached = false;
+		$prefs_cache = array();
+		cachePrefValues($data_dir, $username);
+		setPref($data_dir,$username,'login_alias',$login_alias);
+
         /* change cached prefs back to users */
         $prefs_are_cached = false;
         $prefs_cache = array();
         session_register('prefs_are_cached');
         cachePrefValues($data_dir, $username);
+	
+	}
+    
     }
 }
-?>
\ No newline at end of file
+?>
